@@ -122,10 +122,33 @@ doResolveFormula.data.frame = function(data, f) {
 # @param layer_id
 layerId <- function(
 	layer_id,
-	layer = c("animated_arc", "animated_line", "arc", "bitmap", "cesium", "column",
-						"geojson", "greatcircle","grid","heatmap","hexagon", "i3s",
-						"line", "mesh", "path","pointcloud", "polygon","scatterplot", "screengrid", "terrain",
-						"text", "title","trips")
+	layer = layers <- c(
+		"animated_arc"
+		, "animated_line"
+		, "arc"
+		, "bitmap"
+		, "column"
+		, "cesium"
+		, "i3s"
+		, "geojson"
+		, "greatcircle"
+		, "grid"
+		, "h3"
+		, "heatmap"
+		, "hexagon"
+		, "line"
+		, "mesh"
+		, "path"
+		, "pointcloud"
+		, "polygon"
+		, "scatterplot"
+		, "screengrid"
+		, "terrain"
+		, "text"
+		, "tile3d"
+		, "title"
+		, "trips"
+	)
 	) {
 
 	layer <- match.arg( layer )
@@ -138,3 +161,9 @@ layerId <- function(
 		return(layer_id)
 	}
 }
+
+# returns 0-based index of all the list columns in a data.frame (sf object)
+list_columns <- function(x, geometry_col) {
+	geom_col <- which(names(x) == geometry_col)
+	return( setdiff( which( vapply(x, is.list, T) ), geom_col ) - 1 )
+}
