@@ -16,6 +16,7 @@ function md_setup_window_objects( map_id ) {
   window[map_id + 'mapdeckBounds'] = [];       // store the bounding box of each layer
   window[map_id + 'globalBox'] = [];
   window[map_id + 'currentZoomLevel'] = 0;
+  window[map_id + 'trip_animation'] = 0;
 }
 
 function md_setup_mapdeck_div( map_id ) {
@@ -26,8 +27,8 @@ function md_setup_mapdeck_div( map_id ) {
 function md_setup_legend( map_id ) {
 	var mapDiv = document.getElementById(map_id);
 	var legendContainer = document.createElement('div');
-  legendContainer.className = "legendContainer";
-  legendContainer.id = "legendContainer"+map_id;
+  legendContainer.className = "mapdeckLegendContainer";
+  legendContainer.id = "mapdeckLegendContainer"+map_id;
   mapDiv.appendChild( legendContainer );
 }
 
@@ -91,30 +92,32 @@ function md_update_tooltip({x, y, object, layer, index}) {
     tooltip.style.top = `${y}px`;
     tooltip.style.left = `${x}px`;
     tooltip.innerHTML = `<div>${tt}</div>`;
+
   } else {
   	tooltip.style.display = 'none';
     tooltip.innerHTML = '';
   }
 }
 
-function md_update_binary_tooltip(layer, idx, x, y) {
+function md_update_binary_tooltip({x, y, object, layer, index}) {
 
 	if( !md_div_exists( 'mapdecktooltip'+ layer.props.map_id ) ) {
   	md_setup_tooltip( layer.props.map_id );
   }
 
   const tooltip = document.getElementById( 'mapdecktooltip'+layer.props.map_id );
-  var tt;
 
-	  if( layer.props.data.tooltip && idx >= 0 ) {
-	  	tt = layer.props.data.tooltip[ idx ];
-	  	tooltip.style.display = 'block';
-	    tooltip.style.top = `${y}px`;
-	    tooltip.style.left = `${x}px`;
-	    tooltip.innerHTML = `<div>${tt}</div>`;
-	  } else {
-    	tooltip.style.display = 'none';
-	    tooltip.innerHTML = '';
+  if( layer.props.data.tooltip && index >= 0 ) {
+  	const tt = layer.props.data.tooltip[ index ];
+
+  	tooltip.style.display = 'block';
+    tooltip.style.top = `${y}px`;
+    tooltip.style.left = `${x}px`;
+    tooltip.innerHTML =  `<div>${tt}</div>`;
+
+  } else {
+  	tooltip.style.display = 'none';
+    tooltip.innerHTML = '';
   }
 
 }
@@ -153,24 +156,30 @@ function md_findObjectElementByKey(array, key, value ) {
     return -1;
 }
 
-function md_layer_clear( map_id, map_type, layer_id, layer ) {
+
+function md_layer_clear( map_id, map_type, layer_id, layer, update_view, clear_legend ) {
 
   if( map_type == "mapdeck" ) {
-		md_clear_layer( map_id, layer+'-'+layer_id );
+    md_clear_layer( map_id, layer+'-'+layer_id );
   } else if ( map_type == "google_map" ) {
-  	md_clear_overlay( map_id, layer+'-'+layer_id );
+    md_clear_overlay( map_id, layer+'-'+layer_id );
   }
 
   md_remove_from_bounds( map_id, layer_id );
-	md_update_location( map_id, map_type );
-	md_clear_legend( map_id, map_type, layer_id );
+
+  if( update_view ) {
+	  md_update_location( map_id, map_type );
+  }
+
+  if( clear_legend ) {
+    md_clear_legend( map_id, map_type, layer_id );
+  }
+
 }
 
 
 function md_update_layer( map_id, layer_id, layer ) {
 
-	console.log( layer_id );
-
   var elem = md_findObjectElementByKey( window[map_id + 'map'].props.layers, 'id', layer_id );
   if ( elem != -1 ) {
   	window[ map_id + 'layers'][elem] = layer;
@@ -193,17 +202,17 @@ function md_clear_layer( map_id, layer_id ) {
 
   if ( elem != -1 ) {
   	window[ map_id + 'layers'].splice( elem, 1 );
+
+  	// ## issue 137
+	  //var vs = window[ map_id + 'map'].viewState;
+	  window[map_id + 'map'].setProps({
+	  	layers: [...window[map_id + 'layers'] ]
+	  	//viewState: vs                            // issue 239 & 286
+	  });
+
   }
-
-  // ## issue 137
-  //var vs = window[ map_id + 'map'].viewState;
-  window[map_id + 'map'].setProps({
-  	layers: [...window[map_id + 'layers'] ]
-  	//viewState: vs                            // issue 239 & 286
-  });
 }
 
-
 function md_update_overlay( map_id, layer_id, layer ) {
 
   if ( window[ map_id + 'layers' ] == null ) {
@@ -246,13 +255,15 @@ function md_layer_click( map_id, layer, info ) {
     return;
   }
 
+  console.log(info);
+
   var eventInfo = {
   	index: info.index,
   	color: info.color,
   	object: info.object,
-  	layerId: info.layer_id,
-  	lat: info.lngLat[1],
-  	lon: info.lngLat[0]
+  	layerId: info.layer.id,
+  	lat: info.coordinate[1], // deck.gl 8.4 - https://deck.gl/docs/upgrade-guide#upgrading-from-deckgl-v83-to-v84
+  	lon: info.coordinate[0]
   };
 
   eventInfo = JSON.stringify( eventInfo );
