@@ -41,3 +41,10 @@ test_that("add_grid accepts multiple objects", {
 
 })
 
+test_that("empty data doesn't crash",{
+	## issue 252
+	m <- mapdeck()
+	res <- mapdeck::add_grid(map = m, data = data.frame())
+	expect_true( res$x$calls[[1]]$functions == "md_layer_clear" )
+})
+
